/*
 * Copyright (c) 1993 Addison-Wesley Publishing Company.
 * All rights reserved.  This source code is provided
 * for its instructional value, and is not guaranteed
 * for any particular purpose.
 */
#include <sys/types.h>
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <tiuser.h>
#include <listen.h>

extern int conn(char *, char *);

int
nlps_conn(char *host, char *service)
{
	int fd, len;
	char buf[64];

	/*
	 * Check for invalid service code.
	 */
	if (!service ||
	  (strlen(service) > (size_t)SVC_CODE_SZ)) {
		errno = EINVAL;
		return(-1);
	}

	/*
	 * Connect to the listener (see Example 5.3.1).
	 */
	if ((fd = conn(host, "listen")) < 0)
		return(-1);

	/*
	 * Create and send the NLPS protocol message.
	 * Be sure to transmit the terminating NULL byte.
	 */
	len = sprintf(buf, nls_v0_s, service) + 1;
	if (t_snd(fd, buf, len, 0) != len) {
		t_close(fd);
		return(-1);
	}

	/*
	 * The service should now be available.
	 */
	return(fd);
}
